==> webkitgtk-2.13.2.tar.xz: webkitgtk-2.13.2/Source/WebKit2/NetworkProcess/NetworkSession.h <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef NetworkSession_h
#define NetworkSession_h

#if PLATFORM(COCOA)
OBJC_CLASS NSURLSession;
OBJC_CLASS NSOperationQueue;
OBJC_CLASS WKNetworkSessionDelegate;
#endif

#include "DownloadID.h"
#include "NetworkDataTask.h"
#include <WebCore/SessionID.h>
#include <wtf/HashMap.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>

namespace WebCore {
class NetworkStorageSession;
}

namespace WebKit {

class CustomProtocolManager;

class NetworkSession : public RefCounted<NetworkSession> {
    friend class NetworkDataTask;
public:
    enum class Type {
        Normal,
        Ephemeral
    };

    static Ref<NetworkSession> create(Type, WebCore::SessionID, CustomProtocolManager*, std::unique_ptr<WebCore::NetworkStorageSession>);
    static NetworkSession& defaultSession();
    ~NetworkSession();

    void invalidateAndCancel();

    WebCore::SessionID sessionID() const { return m_sessionID; }
    WebCore::NetworkStorageSession& networkStorageSession();

    static void setCustomProtocolManager(CustomProtocolManager*);
#if PLATFORM(COCOA)
    static void setSourceApplicationAuditTokenData(RetainPtr<CFDataRef>&&);
#endif

#if !USE(CREDENTIAL_STORAGE_WITH_NETWORK_SESSION)
    void clearCredentials();
#endif

    NetworkDataTask* dataTaskForIdentifier(NetworkDataTask::TaskIdentifier, WebCore::StoredCredentials);

    void addDownloadID(NetworkDataTask::TaskIdentifier, DownloadID);
    DownloadID downloadID(NetworkDataTask::TaskIdentifier);
    DownloadID takeDownloadID(NetworkDataTask::TaskIdentifier);
    
private:
    NetworkSession(Type, WebCore::SessionID, CustomProtocolManager*, std::unique_ptr<WebCore::NetworkStorageSession>);

    WebCore::SessionID m_sessionID;
    std::unique_ptr<WebCore::NetworkStorageSession> m_networkStorageSession;

    HashMap<NetworkDataTask::TaskIdentifier, NetworkDataTask*> m_dataTaskMapWithCredentials;
    HashMap<NetworkDataTask::TaskIdentifier, NetworkDataTask*> m_dataTaskMapWithoutCredentials;
    HashMap<NetworkDataTask::TaskIdentifier, DownloadID> m_downloadMap;

#if PLATFORM(COCOA)
    RetainPtr<NSURLSession> m_sessionWithCredentialStorage;
    RetainPtr<WKNetworkSessionDelegate> m_sessionWithCredentialStorageDelegate;
    RetainPtr<NSURLSession> m_sessionWithoutCredentialStorage;
    RetainPtr<WKNetworkSessionDelegate> m_sessionWithoutCredentialStorageDelegate;
#endif
};

} // namespace WebKit

#endif // NetworkSession_h

==> webkitgtk-2.14.2.tar.xz: webkitgtk-2.14.2/Source/WebKit2/NetworkProcess/NetworkSession.h <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if PLATFORM(COCOA)
OBJC_CLASS NSURLSession;
OBJC_CLASS NSOperationQueue;
OBJC_CLASS WKNetworkSessionDelegate;
#endif

#include "DownloadID.h"
#include "NetworkDataTask.h"
#include <WebCore/SessionID.h>
#include <wtf/HashMap.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>

namespace WebCore {
class NetworkStorageSession;
}

namespace WebKit {

class CustomProtocolManager;

class NetworkSession : public RefCounted<NetworkSession> {
    friend class NetworkDataTask;
public:
    enum class Type {
        Normal,
        Ephemeral
    };

    static Ref<NetworkSession> create(Type, WebCore::SessionID, CustomProtocolManager*);
    static NetworkSession& defaultSession();
    ~NetworkSession();

    void invalidateAndCancel();

    WebCore::SessionID sessionID() const { return m_sessionID; }

    static void setCustomProtocolManager(CustomProtocolManager*);
#if PLATFORM(COCOA)
    static void setSourceApplicationAuditTokenData(RetainPtr<CFDataRef>&&);
#endif

    void clearCredentials();

    NetworkDataTask* dataTaskForIdentifier(NetworkDataTask::TaskIdentifier, WebCore::StoredCredentials);

    void addDownloadID(NetworkDataTask::TaskIdentifier, DownloadID);
    DownloadID downloadID(NetworkDataTask::TaskIdentifier);
    DownloadID takeDownloadID(NetworkDataTask::TaskIdentifier);
    
private:
    NetworkSession(Type, WebCore::SessionID, CustomProtocolManager*);
    WebCore::NetworkStorageSession& networkStorageSession();

    WebCore::SessionID m_sessionID;

    HashMap<NetworkDataTask::TaskIdentifier, NetworkDataTask*> m_dataTaskMapWithCredentials;
    HashMap<NetworkDataTask::TaskIdentifier, NetworkDataTask*> m_dataTaskMapWithoutCredentials;
    HashMap<NetworkDataTask::TaskIdentifier, DownloadID> m_downloadMap;

#if PLATFORM(COCOA)
    RetainPtr<NSURLSession> m_sessionWithCredentialStorage;
    RetainPtr<WKNetworkSessionDelegate> m_sessionWithCredentialStorageDelegate;
    RetainPtr<NSURLSession> m_sessionWithoutCredentialStorage;
    RetainPtr<WKNetworkSessionDelegate> m_sessionWithoutCredentialStorageDelegate;
#endif
};

} // namespace WebKit
